import json

import requests


API_URL = "https://traceability.cz/simpleapi"
ORDER_ERP_REF = "PO-PLAYGROUND"
OPERATION = 20
WORKER_ID = 1011
WP_ID = 1010
BARCODE = "TS000000091"


def test1():
    """
    Structured data, list of lists (could tuples).
    """
    data = json.dumps([
        ['P', 'PROGRAM', 'TEST-PROGRAM-1.3.21'],
        ['I', 'GROUP1-test1-NAME1', '2866.71Ohm (Rmin=30.00Ohm)'],
        ['I', 'GROUP1-test1-NAME2', '2272.93Ohm (Rmin=30.00Ohm)'],
        ['D', 'GROUP1-test1-NAME3', '1.24Ohm (Rmin=30.00Ohm)'],
        ['I', 'GROUP1-test2-NAME1', '5.00Ohm (Rmin=30.00Ohm)'],
        ['I', 'GROUP1-test2-NAME2', '2.16Ohm (Rmin=30.00Ohm)'],
        ['I', 'GROUP1-test2-NAME3', '1.18Ohm (Rmin=30.00Ohm)'],
        ['I', 'GROUP2-test1-NAME1', '1.22V (Umin=3.10V, Umax=3.50V)'],
        ['I', 'GROUP2-test1-NAME2', '1.14V (Umin=3.10V, Umax=3.50V)'],
        ['D', 'GROUP2-test2-NAME1', '3.43V (Umin=3.10V, Umax=3.50V)'],
    ])
    result = requests.post(
        "%s/%s" % (API_URL, "addop"),
        data={
            "worker_id": WORKER_ID,
            "wp_id": WP_ID,
            "erp_ref": ORDER_ERP_REF,
            "op": OPERATION,
            "barcode": BARCODE,
            "result": 0,
            "data": data,
        }
    )
    result.raise_for_status()


def test2():
    """
    Data as a structured text.
    """
    data = ["P:PROGRAM=TEST-PROGRAM-1.3.21"]
    for i in range(10):
        data.append("%s:NAME%d=%d" % (
            "D" if 1 == i % 4 else "I",
            (i + 1),
            i * 456461896 % 500,
        ))
    data = "|".join(data)
    result = requests.post(
        "%s/%s" % (API_URL, "addop"),
        data={
            "worker_id": WORKER_ID,
            "wp_id": WP_ID,
            "erp_ref": ORDER_ERP_REF,
            "op": OPERATION,
            "barcode": BARCODE,
            "result": 0,
            "data": data,
        }
    )
    result.raise_for_status()


def test3():
    """
    Unstructured data, for example a file. Each row is stored separately.
    If a row does not contain a =, it is just stored as lineX=...
    If it does contain a =, then it is split on the =.
    """
    data = ["Some text without any structure. The text is quite long.", ]
    for i in range(1000):
        data.append("Line %s of the text being sent as data." % (i+1))
    data = "\n".join(data)
    result = requests.post(
        "%s/%s" % (API_URL, "addop"),
        data={
            "worker_id": WORKER_ID,
            "wp_id": WP_ID,
            "erp_ref": ORDER_ERP_REF,
            "op": OPERATION,
            "barcode": BARCODE,
            "result": 0,
            "data": data,
        }
    )
    result.raise_for_status()


def test4():
    data = """
    ###################
    # SOME test:                #
    ###################

 First test heading:

3.3V Aux = 3291.75Ohm (Rmin=0.00Ohm)
12V Standby = 12196.88Ohm (Rmin=0.00Ohm)
3.3V Switched = 19.39Ohm (Rmin=0.00Ohm)
12V Switched = 148.10Ohm (Rmin=0.00Ohm)
Power = 12259.27Ohm (Rmin=0.00Ohm)

 Second test heading:

3.3V Aux = 3.29V (Umin=3.10V, Umax=3.50V)
12V Standby = 12.20V (Umin=11.70V, Umax=12.50V)
3.3V Switched = -0.00V (Umin=-0.10V, Umax=0.30V)
12V Switched = -0.00V (Umin=-0.10V, Umax=0.30V)
Power = 12.26V (Umin=11.00V, Umax=13.00V)

 Third test heading:

3.3V Aux = 3.28V (Umin=3.10V, Umax=3.50V)
12V Standby = 12.10V (Umin=11.70V, Umax=12.50V)
3.3V Switched = 3.37V (Umin=3.20V, Umax=3.50V)
12V Switched = 12.13V (Umin=11.70V, Umax=12.50V)
Power = 12.18V (Umin=11.00V, Umax=13.00V)

 Final test heading:
PASSED
    """
    result = requests.post(
        "%s/%s" % (API_URL, "addop"),
        data={
            "worker_id": WORKER_ID,
            "wp_id": WP_ID,
            "erp_ref": ORDER_ERP_REF,
            "op": OPERATION,
            "barcode": BARCODE,
            "result": 0,
            "data": data,
        }
    )
    result.raise_for_status()


if "__main__" == __name__:
    pass
    test1()
    test2()
    test3()
    test4()

